@@ -210,6 +210,10 @@ pub fn functions() -> HashSet<&'static str>
         "iden",
         "identity",
         "quartic",
+        "solve",
+        "inter",
+        "interpolate",
+        "unity",
     ]
     .iter()
     .cloned()
