@@ -7,7 +7,7 @@ use crate::{
     parse::input_var,
     print::get_output,
     AngleType::{Degrees, Gradians, Radians},
-    Colors,
+    Colors, GraphType,
     Notation::{LargeEngineering, Normal, Scientific, SmallEngineering},
     Number, Options, Variable,
 };
@@ -15,7 +15,7 @@ use crossterm::{
     execute, terminal,
     terminal::{Clear, ClearType},
 };
-use rug::Complex;
+use rug::{Complex, Float};
 use std::{
     fs::File,
     io::{BufRead, BufReader, Stdout, Write},
@@ -69,7 +69,7 @@ pub fn arg_opts(
                 args.remove(0);
                 break;
             }
-            _ if !args[0].starts_with('-') =>
+            _ if !args[0].starts_with("--") =>
             {
                 break;
             }
@@ -185,7 +185,28 @@ pub fn set_commands(
                 _ => return Err("bad notation type"),
             }
         }
-        "saveto" => colors.graphtofile = r.to_string(),
+        "graph" =>
+        {
+            options.graphtype = match r
+            {
+                "normal" => GraphType::Normal,
+                "null" | "none" => GraphType::None,
+                "depth" => GraphType::Depth,
+                "flat" => GraphType::Flat,
+                _ => return Err("bad graph type"),
+            }
+        }
+        "saveto" =>
+        {
+            if r == "null"
+            {
+                colors.graphtofile.clear()
+            }
+            else
+            {
+                colors.graphtofile = r.to_string()
+            }
+        }
         "re1col" => colors.re1col = r.to_string(),
         "im1col" => colors.im1col = r.to_string(),
         "re2col" => colors.re2col = r.to_string(),
@@ -242,14 +263,14 @@ pub fn set_commands(
                 return Err("Invalid point type");
             }
         }
-        "graphcli" | "slowcheck" | "interactive" | "color" | "prompt" | "depth" | "surface"
-        | "flat" | "rt" | "siunits" | "line" | "lines" | "polar" | "frac" | "multi" | "tabbed"
-        | "comma" | "graph" | "graphing" | "units" | "scalegraph" | "debug" | "vars" | "onaxis"
-        | "base" | "ticks" | "decimal" | "deci" | "decimals" | "graphprec" | "graphprecision"
-        | "prec" | "windowsize" | "precision" | "range" | "xr" | "yr" | "zr" | "vrange" | "vxr"
-        | "vyr" | "vzr" | "2d" | "3d" =>
+        "graphcli" | "slowcheck" | "interactive" | "color" | "prompt" | "surface" | "rt"
+        | "siunits" | "line" | "lines" | "polar" | "frac" | "multi" | "tabbed" | "comma"
+        | "units" | "scalegraph" | "debug" | "vars" | "onaxis" | "base" | "ticks" | "decimal"
+        | "deci" | "decimals" | "graphprec" | "graphprecision" | "prec" | "windowsize"
+        | "precision" | "range" | "xr" | "yr" | "zr" | "vrange" | "vxr" | "vyr" | "vzr" | "2d"
+        | "3d" =>
         {
-            let mut args: Vec<f64> = Vec::new();
+            let mut args: Vec<Float> = Vec::new();
             {
                 let mut bracket = 0;
                 let mut last = 0;
@@ -277,7 +298,7 @@ pub fn set_commands(
                                     .num()?
                                     .number
                                     .real()
-                                    .to_f64(),
+                                    .clone(),
                             );
                             last = i + 1;
                         }
@@ -301,7 +322,7 @@ pub fn set_commands(
                         .num()?
                         .number
                         .real()
-                        .to_f64(),
+                        .clone(),
                 );
             }
             match l
@@ -310,9 +331,7 @@ pub fn set_commands(
                 "color" => options.color = args[0] != 0.0,
                 "interactive" => options.stay_interactive = args[0] != 0.0,
                 "prompt" => options.prompt = args[0] != 0.0,
-                "depth" => options.depth = args[0] != 0.0,
                 "surface" => options.surface = args[0] != 0.0,
-                "flat" => options.flat = args[0] != 0.0,
                 "rt" => options.real_time_output = args[0] != 0.0,
                 "siunits" => options.si_units = args[0] != 0.0,
                 "line" | "lines" => options.lines = args[0] != 0.0,
@@ -321,7 +340,6 @@ pub fn set_commands(
                 "multi" => options.multi = args[0] != 0.0,
                 "tabbed" => options.tabbed = args[0] != 0.0,
                 "comma" => options.comma = args[0] != 0.0,
-                "graph" | "graphing" => options.graph = args[0] != 0.0,
                 "units" => options.units = args[0] != 0.0,
                 "scalegraph" => options.scale_graph = args[0] != 0.0,
                 "debug" => options.debug = args[0] != 0.0,
@@ -331,8 +349,16 @@ pub fn set_commands(
                 {
                     if args.len() == 2
                     {
-                        let n1 = args[0] as i32;
-                        let n2 = args[1] as i32;
+                        let n1 = args[0]
+                            .to_integer()
+                            .unwrap_or_default()
+                            .to_i32()
+                            .unwrap_or_default();
+                        let n2 = args[1]
+                            .to_integer()
+                            .unwrap_or_default()
+                            .to_i32()
+                            .unwrap_or_default();
                         if (2..=36).contains(&n1) && (2..=36).contains(&n2)
                         {
                             options.base = (n1, n2)
@@ -344,7 +370,11 @@ pub fn set_commands(
                     }
                     else
                     {
-                        let n = args[0] as i32;
+                        let n = args[0]
+                            .to_integer()
+                            .unwrap_or_default()
+                            .to_i32()
+                            .unwrap_or_default();
                         if (2..=36).contains(&n)
                         {
                             options.base = (n, n)
@@ -355,11 +385,22 @@ pub fn set_commands(
                         }
                     }
                 }
-                "ticks" => options.ticks = args[0],
-                "slowcheck" => options.slowcheck = args[0] as u128,
+                "ticks" => options.ticks = args[0].to_f64(),
+                "slowcheck" =>
+                {
+                    options.slowcheck = args[0]
+                        .to_integer()
+                        .unwrap_or_default()
+                        .to_u128()
+                        .unwrap_or_default()
+                }
                 "decimal" | "deci" | "decimals" =>
                 {
-                    options.decimal_places = match args[0] as isize
+                    options.decimal_places = match args[0]
+                        .to_integer()
+                        .unwrap_or_default()
+                        .to_isize()
+                        .unwrap_or_default()
                     {
                         -1 => usize::MAX - 1,
                         -2 => usize::MAX,
@@ -367,7 +408,11 @@ pub fn set_commands(
                         _ => return Err("Invalid decimal"),
                     };
                 }
-                "graphprec" | "graphprecision" => match args[0] as u32
+                "graphprec" | "graphprecision" => match args[0]
+                    .to_integer()
+                    .unwrap_or_default()
+                    .to_u32()
+                    .unwrap_or_default()
                 {
                     n if n != 0 => options.graph_prec = n,
                     _ => return Err("Invalid graphprecision"),
@@ -376,14 +421,40 @@ pub fn set_commands(
                 {
                     if args.len() == 1
                     {
-                        options.window_size = (args[0] as usize, args[0] as usize)
+                        options.window_size = (
+                            args[0]
+                                .to_integer()
+                                .unwrap_or_default()
+                                .to_usize()
+                                .unwrap_or_default(),
+                            args[0]
+                                .to_integer()
+                                .unwrap_or_default()
+                                .to_usize()
+                                .unwrap_or_default(),
+                        )
                     }
                     else
                     {
-                        options.window_size = (args[0] as usize, args[1] as usize)
+                        options.window_size = (
+                            args[0]
+                                .to_integer()
+                                .unwrap_or_default()
+                                .to_usize()
+                                .unwrap_or_default(),
+                            args[1]
+                                .to_integer()
+                                .unwrap_or_default()
+                                .to_usize()
+                                .unwrap_or_default(),
+                        )
                     }
                 }
-                "prec" | "precision" => match args[0] as u32
+                "prec" | "precision" => match args[0]
+                    .to_integer()
+                    .unwrap_or_default()
+                    .to_u32()
+                    .unwrap_or_default()
                 {
                     n if n != 0 =>
                     {
@@ -497,7 +568,7 @@ pub fn set_commands(
                 {
                     if args.len() == 1
                     {
-                        let range = args[0];
+                        let range = args[0].to_f64();
                         if range == 0.0
                         {
                             return Err("bad range");
@@ -513,8 +584,8 @@ pub fn set_commands(
                     }
                     else
                     {
-                        let min = args[0];
-                        let max = args[1];
+                        let min = args[0].to_f64();
+                        let max = args[1].to_f64();
                         if min == max
                         {
                             return Err("bad range");
@@ -533,7 +604,7 @@ pub fn set_commands(
                 {
                     if args.len() == 1
                     {
-                        let range = args[0];
+                        let range = args[0].to_f64();
                         if range == 0.0
                         {
                             return Err("bad range");
@@ -542,8 +613,8 @@ pub fn set_commands(
                     }
                     else
                     {
-                        let min = args[0];
-                        let max = args[1];
+                        let min = args[0].to_f64();
+                        let max = args[1].to_f64();
                         if min == max
                         {
                             return Err("bad range");
@@ -555,7 +626,7 @@ pub fn set_commands(
                 {
                     if args.len() == 1
                     {
-                        let range = args[0];
+                        let range = args[0].to_f64();
                         if range == 0.0
                         {
                             return Err("bad range");
@@ -564,8 +635,8 @@ pub fn set_commands(
                     }
                     else
                     {
-                        let min = args[0];
-                        let max = args[1];
+                        let min = args[0].to_f64();
+                        let max = args[1].to_f64();
                         if min == max
                         {
                             return Err("bad range");
@@ -577,7 +648,7 @@ pub fn set_commands(
                 {
                     if args.len() == 1
                     {
-                        let range = args[0];
+                        let range = args[0].to_f64();
                         if range == 0.0
                         {
                             return Err("bad range");
@@ -586,8 +657,8 @@ pub fn set_commands(
                     }
                     else
                     {
-                        let min = args[0];
-                        let max = args[1];
+                        let min = args[0].to_f64();
+                        let max = args[1].to_f64();
                         if min == max
                         {
                             return Err("bad range");
@@ -599,7 +670,7 @@ pub fn set_commands(
                 {
                     if args.len() == 1
                     {
-                        let range = args[0];
+                        let range = args[0].to_f64();
                         if range == 0.0
                         {
                             return Err("bad range");
@@ -615,8 +686,8 @@ pub fn set_commands(
                     }
                     else
                     {
-                        let min = args[0];
-                        let max = args[1];
+                        let min = args[0].to_f64();
+                        let max = args[1].to_f64();
                         if min == max
                         {
                             return Err("bad range");
@@ -635,7 +706,7 @@ pub fn set_commands(
                 {
                     if args.len() == 1
                     {
-                        let range = args[0];
+                        let range = args[0].to_f64();
                         if range == 0.0
                         {
                             return Err("bad range");
@@ -644,8 +715,8 @@ pub fn set_commands(
                     }
                     else
                     {
-                        let min = args[0];
-                        let max = args[1];
+                        let min = args[0].to_f64();
+                        let max = args[1].to_f64();
                         if min == max
                         {
                             return Err("bad range");
@@ -657,7 +728,7 @@ pub fn set_commands(
                 {
                     if args.len() == 1
                     {
-                        let range = args[0];
+                        let range = args[0].to_f64();
                         if range == 0.0
                         {
                             return Err("bad range");
@@ -666,8 +737,8 @@ pub fn set_commands(
                     }
                     else
                     {
-                        let min = args[0];
-                        let max = args[1];
+                        let min = args[0].to_f64();
+                        let max = args[1].to_f64();
                         if min == max
                         {
                             return Err("bad range");
@@ -679,7 +750,7 @@ pub fn set_commands(
                 {
                     if args.len() == 1
                     {
-                        let range = args[0];
+                        let range = args[0].to_f64();
                         if range == 0.0
                         {
                             return Err("bad range");
@@ -688,8 +759,8 @@ pub fn set_commands(
                     }
                     else
                     {
-                        let min = args[0];
-                        let max = args[1];
+                        let min = args[0].to_f64();
+                        let max = args[1].to_f64();
                         if min == max
                         {
                             return Err("bad range");
@@ -697,18 +768,37 @@ pub fn set_commands(
                         options.vzr = (min, max)
                     }
                 }
-                "2d" => options.samples_2d = args[0] as usize,
+                "2d" =>
+                {
+                    options.samples_2d = args[0]
+                        .to_integer()
+                        .unwrap_or_default()
+                        .to_usize()
+                        .unwrap_or_default()
+                }
                 "3d" =>
                 {
                     if args.len() == 1
                     {
-                        let range = args[0] as usize;
+                        let range = args[0]
+                            .to_integer()
+                            .unwrap_or_default()
+                            .to_usize()
+                            .unwrap_or_default();
                         options.samples_3d = (range, range)
                     }
                     else
                     {
-                        let x = args[0] as usize;
-                        let y = args[1] as usize;
+                        let x = args[0]
+                            .to_integer()
+                            .unwrap_or_default()
+                            .to_usize()
+                            .unwrap_or_default();
+                        let y = args[1]
+                            .to_integer()
+                            .unwrap_or_default()
+                            .to_usize()
+                            .unwrap_or_default();
                         options.samples_3d = (x, y)
                     }
                 }
@@ -729,10 +819,8 @@ pub fn silent_commands(options: &mut Options, input: &[char]) -> bool
         "debug" => options.debug = !options.debug,
         "color" => options.color = !options.color,
         "prompt" => options.prompt = !options.prompt,
-        "depth" => options.depth = !options.depth,
         "onaxis" => options.onaxis = !options.onaxis,
         "surface" => options.surface = !options.surface,
-        "flat" => options.flat = !options.flat,
         "rt" => options.real_time_output = !options.real_time_output,
         "siunits" => options.si_units = !options.si_units,
         "line" | "lines" => options.lines = !options.lines,
@@ -741,8 +829,7 @@ pub fn silent_commands(options: &mut Options, input: &[char]) -> bool
         "multi" => options.multi = !options.multi,
         "tabbed" => options.tabbed = !options.tabbed,
         "comma" => options.comma = !options.comma,
-        "graph" | "graphing" => options.graph = !options.graph,
-        "units" => options.graph = !options.units,
+        "units" => options.units = !options.units,
         "vars" => options.allow_vars = !options.allow_vars,
         "graphcli" => options.graph_cli = !options.graph_cli,
         _ => return false,
@@ -791,12 +878,6 @@ pub fn commands(
             stdout.flush().unwrap();
             options.prompt = !options.prompt;
         }
-        "depth" =>
-        {
-            print!("\x1b[G\x1b[A\x1b[K");
-            stdout.flush().unwrap();
-            options.depth = !options.depth;
-        }
         "onaxis" =>
         {
             print!("\x1b[G\x1b[A\x1b[K");
@@ -809,12 +890,6 @@ pub fn commands(
             stdout.flush().unwrap();
             options.surface = !options.surface;
         }
-        "flat" =>
-        {
-            print!("\x1b[G\x1b[A\x1b[K");
-            stdout.flush().unwrap();
-            options.flat = !options.flat;
-        }
         "rt" =>
         {
             print!("\x1b[G\x1b[A\x1b[K");
@@ -881,12 +956,6 @@ pub fn commands(
             stdout.flush().unwrap();
             options.comma = !options.comma;
         }
-        "graph" | "graphing" =>
-        {
-            print!("\x1b[G\x1b[A\x1b[K");
-            stdout.flush().unwrap();
-            options.graph = !options.graph;
-        }
         "units" =>
         {
             print!("\x1b[G\x1b[A\x1b[K");
@@ -1064,9 +1133,7 @@ pub fn equal_to(options: Options, colors: &Colors, vars: &[Variable], l: &str, l
         "slowcheck" => format!("{}", options.slowcheck),
         "label" => format!("{},{},{}", colors.label.0, colors.label.1, colors.label.2),
         "color" => format!("{}", options.color),
-        "depth" => format!("{}", options.depth),
         "surface" => format!("{}", options.surface),
-        "flat" => format!("{}", options.flat),
         "prompt" => format!("{}", options.prompt),
         "rt" => format!("{}", options.real_time_output),
         "siunits" => format!("{}", options.si_units),
@@ -1078,7 +1145,6 @@ pub fn equal_to(options: Options, colors: &Colors, vars: &[Variable], l: &str, l
         "multi" => format!("{}", options.multi),
         "tabbed" => format!("{}", options.tabbed),
         "comma" => format!("{}", options.comma),
-        "graph" | "graphing" => format!("{}", options.graph),
         "units" => format!("{}", options.units),
         "graphcli" => format!("{}", options.graph_cli),
         "point" => format!("{}", options.point_style),
@@ -1125,6 +1191,14 @@ pub fn equal_to(options: Options, colors: &Colors, vars: &[Variable], l: &str, l
             Normal => "n",
         }
         .to_string(),
+        "graph" => match options.graphtype
+        {
+            GraphType::Normal => "normal",
+            GraphType::None => "none",
+            GraphType::Depth => "depth",
+            GraphType::Flat => "flat",
+        }
+        .to_string(),
         "interactive" => format!("{}", options.interactive),
         "textc" => colors.text.to_string(),
         "promptc" => colors.prompt.to_string(),
