@@ -104,7 +104,7 @@ pub fn print_concurrent(
                 options,
                 &colors,
                 &vars,
-                &tempinput[..tempinput.len() - 1],
+                &tempinput[..tempinput.len().saturating_sub(1)],
                 &last.iter().collect::<String>(),
             );
             return if !out.is_empty()
@@ -205,6 +205,7 @@ pub fn print_concurrent(
                     | "re6col"
                     | "im6col"
                     | "notation"
+                    | "graph"
                     | "textc"
                     | "promptc"
                     | "imagc"
@@ -404,7 +405,7 @@ pub fn print_concurrent(
                     }
                     else
                     {
-                        (i.len() - 1) / width + 1
+                        (i.len().saturating_sub(1)) / width + 1
                     }
                 })
                 .sum();
@@ -852,7 +853,7 @@ pub fn print_concurrent(
                     output += "\x1b[0m";
                     frac_out += "\x1b[0m";
                 }
-                if k == v.len() - 1
+                if k == v.len().saturating_sub(1)
                 {
                     output += if options.polar { "]" } else { "}" };
                     frac_out += if options.polar { "]" } else { "}" };
@@ -1017,7 +1018,7 @@ pub fn print_concurrent(
                         output += "\x1b[0m";
                         frac_out += "\x1b[0m";
                     }
-                    if k == j.len() - 1
+                    if k == j.len().saturating_sub(1)
                     {
                         if !options.multi
                         {
@@ -1036,7 +1037,7 @@ pub fn print_concurrent(
                         frac_out += ",";
                     }
                 }
-                if l != v.len() - 1
+                if l != v.len().saturating_sub(1)
                 {
                     if options.multi
                     {
@@ -1057,7 +1058,7 @@ pub fn print_concurrent(
                 frac_out += "}";
             }
             let (width, height) = get_terminal_dimensions();
-            let length = no_col(&output, options.color).len() - 1;
+            let length = no_col(&output, options.color).len().saturating_sub(1);
             if frac_out != output
             {
                 frac = 1;
@@ -1223,7 +1224,7 @@ pub fn print_answer(num: NumStr, options: Options, colors: &Colors)
                 {
                     output += "\x1b[0m";
                 }
-                output += if k == v.len() - 1
+                output += if k == v.len().saturating_sub(1)
                 {
                     if options.polar
                     {
@@ -1268,7 +1269,7 @@ pub fn print_answer(num: NumStr, options: Options, colors: &Colors)
                     {
                         output += "\x1b[0m";
                     }
-                    if k == j.len() - 1
+                    if k == j.len().saturating_sub(1)
                     {
                         if !options.multi
                         {
@@ -1284,7 +1285,7 @@ pub fn print_answer(num: NumStr, options: Options, colors: &Colors)
                         output += ",";
                     }
                 }
-                if l != v.len() - 1
+                if l != v.len().saturating_sub(1)
                 {
                     if options.multi
                     {
@@ -1538,7 +1539,7 @@ pub fn get_output(
     }
     else
     {
-        let re = if options.comma
+        let mut re = if options.comma
         {
             add_commas(&to_string(
                 num.real(),
@@ -1551,7 +1552,7 @@ pub fn get_output(
         {
             to_string(num.real(), options.decimal_places, false, options.base.1)
         };
-        let im = if options.comma
+        let mut im = if options.comma
         {
             add_commas(&to_string(
                 num.imag(),
@@ -1564,6 +1565,14 @@ pub fn get_output(
         {
             to_string(num.imag(), options.decimal_places, true, options.base.1)
         };
+        if re == "-0"
+        {
+            re.remove(0);
+        }
+        if im == "-0"
+        {
+            im.remove(0);
+        }
         let sign = if num.imag().is_sign_positive() && re != "0"
         {
             "+"
@@ -1651,14 +1660,7 @@ fn to_string(num: &Float, decimals: usize, imag: bool, radix: i32) -> String
     let mut neg = if neg { "-" } else { "" };
     if exp.is_none()
     {
-        return if str == "0"
-        {
-            "0".to_string()
-        }
-        else
-        {
-            format!("{}{}", neg, str)
-        };
+        return format!("{}{}", neg, str);
     }
     let exp = exp.unwrap();
     let width = get_terminal_dimensions().0;
@@ -1680,14 +1682,7 @@ fn to_string(num: &Float, decimals: usize, imag: bool, radix: i32) -> String
     };
     if str.len() as i32 == exp
     {
-        return if str == "0"
-        {
-            neg.to_owned() + "0"
-        }
-        else
-        {
-            format!("{}{}", neg, str)
-        };
+        return format!("{}{}", neg, str);
     }
     if exp > str.len() as i32
     {
@@ -1713,14 +1708,7 @@ fn to_string(num: &Float, decimals: usize, imag: bool, radix: i32) -> String
     let mut r = split.next().unwrap().to_string();
     if r.is_empty()
     {
-        return if str == "0"
-        {
-            neg.to_owned() + "0"
-        }
-        else
-        {
-            format!("{}{}", neg, l)
-        };
+        return format!("{}{}", neg, l);
     }
     if r.len() > decimals
     {
@@ -1941,7 +1929,14 @@ fn remove_trailing_zeros(input: &str, dec: usize, prec: u32) -> String
             sign + num.trim_end_matches('0').trim_end_matches('.')
                 + "e"
                 + &(input[pos + 1..].parse::<isize>().unwrap()
-                    + if num.len() - 1 > dec { 1 } else { 0 })
+                    + if num.len().saturating_sub(1) > dec
+                    {
+                        1
+                    }
+                    else
+                    {
+                        0
+                    })
                 .to_string()
         }
     }
