@@ -576,7 +576,7 @@ pub fn is_unit(unit: &mut String) -> bool
 {
     units().contains(unit.as_str())
         || (unit.len() > 2 && unit.ends_with('s') && {
-            let is_true = units().contains(&unit[..unit.len() - 1]);
+            let is_true = units().contains(&unit[..unit.len().saturating_sub(1)]);
             is_true && {
                 unit.pop();
                 true
@@ -851,6 +851,12 @@ pub fn units() -> HashSet<&'static str>
         "gal",
         "gallon",
         "floz",
+        "lbf",
+        "parsec",
+        "pc",
+        "au",
+        "arcsec",
+        "arcmin",
     ]
     .iter()
     .cloned()
@@ -949,15 +955,15 @@ pub fn to_unit(unit: String, mut num: Complex, options: Options) -> (Number, Opt
         }
         "mph" =>
         {
-            num *= 201168;
-            num /= 125;
-            num /= 3600;
+            num *= 1397;
+            num /= 3125;
             units.meter = 1.0;
             units.second = -1.0;
         }
         "kph" =>
         {
-            num /= 3.6;
+            num *= 5;
+            num /= 18;
             units.meter = 1.0;
         }
         "mi" | "mile" =>
@@ -972,6 +978,17 @@ pub fn to_unit(unit: String, mut num: Complex, options: Options) -> (Number, Opt
             num /= 1250;
             units.meter = 1.0;
         }
+        "parsec" | "pc" =>
+        {
+            units.meter = 1.0;
+            num *= 648000 / Complex::with_val(options.prec, Pi);
+            num *= 149597870700u64;
+        }
+        "au" =>
+        {
+            units.meter = 1.0;
+            num *= 149597870700u64;
+        }
         "ft" | "foot" | "feet" =>
         {
             units.meter = 1.0;
@@ -997,8 +1014,8 @@ pub fn to_unit(unit: String, mut num: Complex, options: Options) -> (Number, Opt
         }
         "floz" =>
         {
-            num *= 1420653;
-            num /= 50000000000u64;
+            num *= 473176473;
+            num /= 16000000000000u64;
             units.meter = 3.0;
         }
         "gallon" | "gal" =>
@@ -1110,7 +1127,7 @@ pub fn to_unit(unit: String, mut num: Complex, options: Options) -> (Number, Opt
         "psi" =>
         {
             num *= 6894757;
-            num /= 1000000;
+            num /= 1000;
             units.kilogram = 1.0;
             units.meter = -1.0;
             units.second = -2.0;
@@ -1190,7 +1207,7 @@ pub fn to_unit(unit: String, mut num: Complex, options: Options) -> (Number, Opt
         "ly" =>
         {
             num *= 9460730472580800u128;
-            units.second = 1.0;
+            units.meter = 1.0;
         }
         "N" | "newton" =>
         {
@@ -1198,11 +1215,63 @@ pub fn to_unit(unit: String, mut num: Complex, options: Options) -> (Number, Opt
             units.meter = 1.0;
             units.second = -2.0;
         }
+        "lbf" =>
+        {
+            num *= 8896443230521u64;
+            num /= 2000000000000u64;
+            units.kilogram = 1.0;
+            units.meter = 1.0;
+            units.second = -2.0;
+        }
         "C" | "coulomb" =>
         {
             units.ampere = 1.0;
             units.second = 1.0;
         }
+        "arcmin" =>
+        {
+            match options.angle
+            {
+                AngleType::Degrees =>
+                {
+                    num /= 60;
+                }
+                AngleType::Gradians =>
+                {
+                    num *= 200;
+                    num /= 180;
+                    num /= 60;
+                }
+                AngleType::Radians =>
+                {
+                    num *= Complex::with_val(options.prec, Pi) / 180;
+                    num /= 60;
+                }
+            };
+            units.angle = 1.0;
+        }
+        "arcsec" =>
+        {
+            match options.angle
+            {
+                AngleType::Degrees =>
+                {
+                    num /= 3600;
+                }
+                AngleType::Gradians =>
+                {
+                    num *= 200;
+                    num /= 180;
+                    num /= 3600;
+                }
+                AngleType::Radians =>
+                {
+                    num *= Complex::with_val(options.prec, Pi) / 180;
+                    num /= 3600;
+                }
+            };
+            units.angle = 1.0;
+        }
         "°" | "deg" | "degree" =>
         {
             match options.angle
